@@ -15,9 +15,9 @@
 // | Author: Bertrand Mansion <bmansion@mamasam.com>                     |
 // +---------------------------------------------------------------------+
 //
-// $Id: Container.php,v 1.30 2003/11/29 11:02:37 mansion Exp $
+// $Id: Container.php,v 1.35 2004/10/19 00:57:58 ryansking Exp $
 
-require_once('Config.php');
+require_once 'Config.php';
 
 /**
 * Interface for Config containers
@@ -50,7 +50,7 @@ class Config_Container {
     * Container object children
     * @var  array
     */
-    var $children;
+    var $children = array();
 
     /**
     * Reference to container object's parent
@@ -124,7 +124,7 @@ class Config_Container {
         if (is_null($target)) {
             $target =& $this;
         }
-        if (get_class($target) != 'config_container') {
+        if (strtolower(get_class($target)) != 'config_container') {
             return PEAR::raiseError('Target must be a Config_Container object in Config_Container::addItem.', null, PEAR_ERROR_RETURN);
         }
 
@@ -298,12 +298,16 @@ class Config_Container {
     } // end func &getItem
 
     /**
-    * Finds a node using XPATH like format:
+    * Finds a node using XPATH like format.
     * 
-    * search format = array ( item,item,item,item)
-    * item = 'string' .. will match the <string of the xml element
-    * item = array('string',array('name'=>'xyz'))
-    *       .. will match <string name="xyz">
+    * The search format is an array:
+    * array(item1, item2, item3, ...)
+    *
+    * Each item can be defined as the following:
+    * item = 'string' : will match the container named 'string'
+    * item = array('string', array('name' => 'xyz'))
+    * will match the container name 'string' whose attribute name is equal to "xyz"
+    * For example : <string name="xyz">
     * 
     * @param    mixed   Search path and attributes
     * 
@@ -337,6 +341,51 @@ class Config_Container {
         return $match;
     } // end func &searchPath
 
+    /**
+    * Return a child directive's content.
+    * 
+    * This method can use two different search approach, depending on
+    * the parameter it is given. If the parameter is an array, it will use
+    * the {@link Config_Container::searchPath()} method. If it is a string, 
+    * it will use the {@link Config_Container::getItem()} method.
+    *
+    * Example:
+    * <code>
+    * require_once 'Config.php';
+    * $ini = new Config();
+    * $conf =& $ini->parseConfig('/path/to/config.ini', 'inicommented');
+    *
+    * // Will return the value found at :
+    * // [Database]
+    * // host=localhost
+    * echo $conf->directiveContent(array('Database', 'host')));
+    *
+    * // Will return the value found at :
+    * // date="dec-2004"
+    * echo $conf->directiveContent('date');
+    *
+    * </code>
+    *
+    * @param    mixed   Search path and attributes or a directive name
+    * @param    int     Index of the item in the returned directive list.
+    *                   Eventually used if args is a string.
+    * 
+    * @return   mixed   Content of directive or false if not found.
+    * @access   public
+    */
+    function directiveContent($args, $index = -1)
+    {
+        if (is_array($args)) {
+            $item =& $this->searchPath($args);
+        } else {
+            $item =& $this->getItem('directive', $args, null, null, $index);
+        }
+        if ($item) {
+            return $item->getContent();
+        }
+        return false;
+    } // end func getDirectiveContent
+
     /**
     * Returns how many children this container has
     *
@@ -346,9 +395,6 @@ class Config_Container {
     */
     function countChildren($type = null, $name = null)
     {
-        if ($this->type != 'section') {
-            return PEAR::raiseError('Config_Container::getChildrenNum must be called on a section type object.', null, PEAR_ERROR_RETURN);
-        }
         if (is_null($type) && is_null($name)) {
             return count($this->children);
         }
@@ -456,7 +502,7 @@ class Config_Container {
     */
     function &getChild($index = 0)
     {
-        if (isset($this->children[$index])) {
+        if (!empty($this->children[$index])) {
             return $this->children[$index];
         } else {
             return false;
@@ -693,7 +739,8 @@ class Config_Container {
         $className = $GLOBALS['CONFIG_TYPES'][$configType][1];
         include_once($includeFile);
 
-        if (in_array('writedatasrc', get_class_methods($className))) {
+        $writeMethodName = (version_compare(phpversion(), '5', '<')) ? 'writedatasrc' : 'writeDatasrc';
+        if (in_array($writeMethodName, get_class_methods($className))) {
             $writer = new $className($options);
             return $writer->writeDatasrc($datasrc, $this);
         }
